@@ -134,7 +134,8 @@ def group_assignment(tlist):
 def group_comparison(tlist):
 
     def _parts_valid(token):
-        return (token.ttype in (T.String.Symbol, T.Name, T.Number,
+        return (token.ttype in (T.String.Symbol, T.String.Single,
+                                T.Name, T.Number, T.Number.Float,
                                 T.Number.Integer, T.Literal,
                                 T.Literal.Number.Integer, T.Name.Placeholder)
                 or isinstance(token, (sql.Identifier, sql.Parenthesis))
